@@ -610,7 +610,7 @@ storage of variables templates")%location)
         reFilter = False
         if varsFilter:
             try:
-                reFilter = re.compile("^%s$"%varsFilter)
+                reFilter = re.compile("%s"%varsFilter)
             except:
                 cl_overriding.printERROR(_("wrong vars filter '%s'")\
                                          %str(varsFilter))
